FirestoreEntity class

Annotation used to mark a class as a Firestore entity.

Keep this intentionally small to avoid depending on analyzer-only APIs.

Constructors

FirestoreEntity({String? collection})
const

Properties

collection String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited